@@ -1,7 +1,7 @@
 """ECO ID to Evidence code group dictionary from evidenceontology"""
 
 # pylint: disable=too-many-lines
-# 1239 ECO IDs
+# 1295 ECO IDs
 ECO2GRP = {
     'ECO:0000030': 'ISA',
     'ECO:0000031': 'ISA',
@@ -232,6 +232,8 @@ ECO2GRP = {
     'ECO:0001585': 'IMP',
     'ECO:0001587': 'IEA',
     'ECO:0001588': 'EXP',
+    'ECO:0001590': 'IEA',
+    'ECO:0001591': 'IDA',
     'ECO:0001593': 'IEA',
     'ECO:0001594': 'EXP',
     'ECO:0001599': 'IEA',
@@ -248,10 +250,17 @@ ECO2GRP = {
     'ECO:0001841': 'IEP',
     'ECO:0001843': 'IEA',
     'ECO:0001844': 'IMP',
+    'ECO:0001846': 'IEA',
+    'ECO:0001847': 'IDA',
     'ECO:0005501': 'IDA',
     'ECO:0005523': 'EXP',
     'ECO:0005527': 'EXP',
     'ECO:0005530': 'IMP',
+    'ECO:0005542': 'EXP',
+    'ECO:0005543': 'EXP',
+    'ECO:0005544': 'ISO',
+    'ECO:0005546': 'ISS',
+    'ECO:0005547': 'NAS',
     'ECO:0005556': 'ISA',
     'ECO:0005557': 'IEA',
     'ECO:0005558': 'ISA',
@@ -268,6 +277,7 @@ ECO2GRP = {
     'ECO:0005595': 'IDA',
     'ECO:0005597': 'IDA',
     'ECO:0005601': 'IDA',
+    'ECO:0005610': 'ISS',
     'ECO:0005613': 'EXP',
     'ECO:0005614': 'IDA',
     'ECO:0005615': 'IEP',
@@ -467,6 +477,8 @@ ECO2GRP = {
     'ECO:0006276': 'IEA',
     'ECO:0006277': 'IPI',
     'ECO:0006278': 'IEA',
+    'ECO:0006279': 'IPI',
+    'ECO:0006280': 'IEA',
     'ECO:0006281': 'IDA',
     'ECO:0006282': 'IEA',
     'ECO:0006283': 'EXP',
@@ -517,6 +529,48 @@ ECO2GRP = {
     'ECO:0006328': 'IEA',
     'ECO:0006329': 'IPI',
     'ECO:0006330': 'IEA',
+    'ECO:0006352': 'IDA',
+    'ECO:0006353': 'IEA',
+    'ECO:0006354': 'IDA',
+    'ECO:0006355': 'IEA',
+    'ECO:0006356': 'IDA',
+    'ECO:0006357': 'IEA',
+    'ECO:0006358': 'IDA',
+    'ECO:0006359': 'IEA',
+    'ECO:0006360': 'IDA',
+    'ECO:0006361': 'IEA',
+    'ECO:0006362': 'IDA',
+    'ECO:0006363': 'IEA',
+    'ECO:0006364': 'IDA',
+    'ECO:0006365': 'IEA',
+    'ECO:0006366': 'IDA',
+    'ECO:0006367': 'IEA',
+    'ECO:0006368': 'EXP',
+    'ECO:0006369': 'IEA',
+    'ECO:0006370': 'EXP',
+    'ECO:0006371': 'IEA',
+    'ECO:0006373': 'IEA',
+    'ECO:0006374': 'EXP',
+    'ECO:0006375': 'IEA',
+    'ECO:0006376': 'EXP',
+    'ECO:0006377': 'IEA',
+    'ECO:0006378': 'IDA',
+    'ECO:0006379': 'IEA',
+    'ECO:0006380': 'IDA',
+    'ECO:0006381': 'IEA',
+    'ECO:0006382': 'IDA',
+    'ECO:0006383': 'IEA',
+    'ECO:0006384': 'EXP',
+    'ECO:0006385': 'IEA',
+    'ECO:0006386': 'EXP',
+    'ECO:0006387': 'IEA',
+    'ECO:0006388': 'IPI',
+    'ECO:0006389': 'IEA',
+    'ECO:0006390': 'EXP',
+    'ECO:0006391': 'IEA',
+    'ECO:0006392': 'IPI',
+    'ECO:0006393': 'IEA',
+    'ECO:0006397': 'IEA',
     'ECO:0007001': 'HMP',
     'ECO:0007003': 'HGI',
     'ECO:0007005': 'HDA',
@@ -558,7 +612,7 @@ ECO2GRP = {
     'ECO:0007082': 'EXP',
     'ECO:0007084': 'IDA',
     'ECO:0007086': 'IDA',
-    'ECO:0007087': 'IEP',
+    'ECO:0007088': 'IEP',
     'ECO:0007089': 'IMP',
     'ECO:0007092': 'IMP',
     'ECO:0007093': 'EXP',
@@ -1148,6 +1202,8 @@ ECO2GRP = {
     'ECO:0007740': 'EXP',
     'ECO:0007741': 'EXP',
     'ECO:0007742': 'EXP',
+    'ECO:0007746': 'NAS',
+    'ECO:0007747': 'EXP',
     'ECO:0007749': 'ISA',
     'ECO:0007752': 'IC',
     'ECO:0007753': 'IC',
